import argparse
from datetime import datetime
import sys
from time import sleep
import urllib.parse
import zmq

parser = argparse.ArgumentParser(
    description='Request dark characterization. Will wait on data transfers to complete first!')
parser.add_argument('--proposal', type=str, help='The proposal number, without leading p, but with leading zeros')
parser.add_argument('--instrument', type=str, choices=["SPB", "MID", "FXE", "SCS", "SQS", "HED"], help='The instrument')
parser.add_argument('--cycle', type=str, help='The facility cycle')
parser.add_argument('--run-high', type=str, help='Run number of high gain data as an integer')
parser.add_argument('--run-med', type=str, help='Run number of medium gain data as an integer')
parser.add_argument('--run-low', type=str, help='Run number of low gain data as an integer')

args = vars(parser.parse_args())

con = zmq.Context()
socket = con.socket(zmq.REQ)
con = socket.connect("tcp://max-exfl016:5555")
uuid = str(datetime.now().timestamp().as_integer_ratio()[0])+args["run_high"]
msg = "','".join(["dark", uuid, "SASEX", args["instrument"], args["cycle"], args["proposal"], "(\"run-high\", \"{}\")".format(args["run_high"]), "(\"run-med\", \"{}\")".format(args["run_med"]), "(\"run-low\", \"{}\")".format(args["run_low"])])
socket.send("['{}']".format(msg).encode())
resp = socket.recv_multipart()[0]
print(resp.decode())
while True:
    socket.send("['query-rid', '{}']".format(uuid).encode())
    resp = socket.recv_multipart()[0]
    rl = resp.decode().split("\n")
    r = ["QUEUE" if "QUEUE" in r else r for r in rl]
    r = " | ".join(r)
    print(r+"\r", end=' ', flush=True)
    sleep(10)

    

